Crate kubewarden_policy_sdk

Crate kubewarden_policy_sdk 

Re-exports

pub use wapc_guest;

Modules

crdcrd
Rust types of Kubewarden CRDs
host_capabilities
logging
This module provides a way to propagate log events from a kubewarden policy to the host runtime.
metadata
request
response
settings
test

Functions

accept_request
Create an acceptance response
mutate_pod_spec_from_requestcluster-context
Update the pod sec from the resource defined in the original object and create an acceptance response.
mutate_request
Create an acceptance response that mutates the original object
protocol_version_guest
Helper function that provides the protocol_version implementation
reject_request
Create a rejection response
validate_settings
waPC guest function to register under the name validate_settings