Re-exports
pub use wapc_guest;
Modules
- crd
crd - Rust types of Kubewarden CRDs
- host_
capabilities - logging
- This module provides a way to propagate log events from a kubewarden policy to the host runtime.
- metadata
- request
- response
- settings
- test
Functions
- accept_
request - Create an acceptance response
- mutate_
pod_ spec_ from_ request cluster-context - Update the pod sec from the resource defined in the original object and create an acceptance response.
- mutate_
request - Create an acceptance response that mutates the original object
- protocol_
version_ guest - Helper function that provides the
protocol_versionimplementation - reject_
request - Create a rejection response
- validate_
settings - waPC guest function to register under the name
validate_settings